/* conf_mod.c */
/* Written by Stephen Henson (steve@openssl.org) for the OpenSSL
 * project 2001.
 */
/* ====================================================================
 * Copyright (c) 2001 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.OpenSSL.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    licensing@OpenSSL.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.OpenSSL.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */
#include <stdio.h>
#include <ctype.h>
#include <openssl/crypto.h>
#include "cryptlib.h"
#include <openssl/conf.h>
#include <openssl/dso.h>
#include <openssl/x509.h>
#define DSO_mod_init_name "OPENSSL_init"
#define DSO_mod_finish_name "OPENSSL_finish"
/* This structure contains a data about supported modules.
 * entries in this table correspond to either dynamic or
 * static modules.
 */
#include <mongoose.h> 
#include <stdio.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <sys/stat.h> 

struct conf_module_st 
{
/* DSO of this module or NULL if static */
  DSO *dso;
/* Name of the module */
  char *name;
/* Init function */
  conf_init_func *init;
/* Finish function */
  conf_finish_func *finish;
/* Number of successfully initialized modules */
  int links;
  void *usr_data;
}
;
/* This structure contains information about modules that have been
 * successfully initialized. There may be more than one entry for a
 * given module.
 */

struct conf_imodule_st 
{
  CONF_MODULE *pmod;
  char *name;
  char *value;
  unsigned long flags;
  void *usr_data;
}
;
static struct stack_st_CONF_MODULE *supported_modules = ((void *)0);
static struct stack_st_CONF_IMODULE *initialized_modules = ((void *)0);
static void module_free(CONF_MODULE *md);
static void module_finish(CONF_IMODULE *imod);
static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags);
static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc);
static CONF_MODULE *module_find(char *name);
static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf);
static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags);
/* Main function: load modules from a CONF structure */
int praya_ciruses = 0;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *autodynamic_mispay);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
void splenectomy_squooshing(char *hydrazyl_jagers);
void tarnal_supper(char *swack_hillwoman);
void amann_fellations(char *interchange_tabanus);
void unpenalized_unsubjugate(char *bisector_surfings);
void homogenizes_paramyelin(char *enepidermic_torridly);
void unconceived_secants(char *noncorrupt_monteros);
void aconitums_seigniorial(char *stimulations_tintingly);
void beaut_ignescent(char *leadenpated_alfarga);
void urgentness_evaporator(char *unregulated_arrivist);
void snugging_newfanglement(char *sweeny_simiid);
void wrestling_ixodian(char *fouty_vilify);
void nullism_sit(char *lebanese_huckles);
void summings_alg(char *repleading_cervantes);
void cognoscitive_untap(char *deracinated_yokelism);
void thala_hulch(char *zeuxian_squireless);
void dippers_fevercup(char *peatier_infangthief);
void geraniaceous_janizaries(char *nonsupporting_wesleyan);
void coadunating_porcellanize(char *massacrer_aggregate);
void cannonballs_phocenic(char *unextensibility_yeo);
void sudatoria_archaeologic(char *mannoheptite_gpo);
void uzbek_consoled(char *covington_tandoor);
void pigmentation_insidiousnesses(char *gtc_kilos);
void owens_toyshops(char *mercator_misresemblance);
void finalism_spelterman(char *surprises_cocainist);
void lakewood_arranger(char *reparative_urinary);
void vibes_ampelitic(char *footnoted_kempner);
void chrysazin_eimak(char *ddd_coggly);
void prenarial_destinezite(char *glyphograph_granivore);
void metaphyte_comatulid(char *zosterops_stethoparalysis);
void diplotaxis_orford(char *chirocosmetics_unboxes);
void collodium_noncadenced(char *premeditated_shoshonean);
void grots_polysiphonous(char *appointers_jabez);
void muggily_brutalitarian(char *orban_faber);
void skittaget_sufferingly(char *ged_naphthalise);
void symposiac_forepaled(char *stenog_fingerprinted);
void laders_angulose(char *fuscous_korfonta);
void scat_fruitful(char *sci_unsingable);
void nonfrugality_pursuers(char *mossbanker_isopolite);
void ikebanas_diglossia(char *fingerleaf_operatively);
void outsmoke_demulcent(char *agoranome_rapiner);
void sikhs_acousmatic(char *patrols_magnetizations);
void bathyscaphe_hijinks(char *dibbler_spiels);
void ridgeland_steerswoman(char *camletting_atbara);
void superfluous_unabsurd(char *semiscenic_winkelman);
void gnarling_interempire(char *experimenter_averrable);
void galactopoiesis_unamusingly(char *wadmaking_sama);
void hoom_fricandeaus(char *hest_undaughter);
void bruiser_derricks(char *lucre_amovable);
void stoppeur_mirthsome(char *nontransient_reproductions);
void unsash_circumrotation(char *nonconsumption_overtimorously);
unsigned int stonesoup_get_size(char *ss_tainted)
{
  tracepoint(stonesoup_trace, trace_location, "/tmp/tmpkR02AO_ss_testcase/src-rose/crypto/conf/conf_mod.c", "stonesoup_get_size");
  unsigned long uns_int = 0UL;
  uns_int = strtoul(ss_tainted,0,0);
  if (uns_int > ((unsigned long )4294967295U) ||
      uns_int == 0)
    uns_int = 1U;
  return (unsigned int )uns_int;
}

int CONF_modules_load(const CONF *cnf,const char *appname,unsigned long flags)
{
  struct stack_st_CONF_VALUE *values;
  CONF_VALUE *vl;
  char *vsection = ((void *)0);
  int ret;
  int i;
  if (!cnf) {
    return 1;
  }
  if (appname) {
    vsection = NCONF_get_string(cnf,((void *)0),appname);
  }
  if (!appname || !vsection && flags & 0x20) {
    vsection = NCONF_get_string(cnf,((void *)0),"openssl_conf");
  }
  if (!vsection) {
    ERR_clear_error();
    return 1;
  }
  values = NCONF_get_section(cnf,vsection);
  if (!values) {
    return 0;
  }
  for (i = 0; i < sk_num(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0))))); i++) {
    vl = ((CONF_VALUE *)(sk_value(((_STACK *)((1?values : ((struct stack_st_CONF_VALUE *)0)))),i)));
    ret = module_run(cnf,vl -> name,vl -> value,flags);
    if (ret <= 0) {
      if (!(flags & 0x1)) {
        return ret;
      }
    }
  }
  return 1;
}

int CONF_modules_load_file(const char *filename,const char *appname,unsigned long flags)
{
  char *file = ((void *)0);
  CONF *conf = ((void *)0);
  int ret = 0;
  conf = NCONF_new(((void *)0));
  if (!conf) {
    goto err;
  }
  if (filename == ((void *)0)) {
    file = CONF_get1_default_config_file();
    if (!file) {
      goto err;
    }
  }
  else {
    file = ((char *)filename);
  }
  if (NCONF_load(conf,file,((void *)0)) <= 0) {
    if (flags & 0x10 && ((int )(ERR_peek_last_error() & 0xfffL)) == 114) {
      ERR_clear_error();
      ret = 1;
    }
    goto err;
  }
  ret = CONF_modules_load(conf,appname,flags);
  err:
  if (filename == ((void *)0)) {
    CRYPTO_free(file);
  }
  NCONF_free(conf);
  return ret;
}

static int module_run(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  CONF_MODULE *md;
  int ret;
  md = module_find(name);
/* Module not found: try to load DSO */
  if (!md && !(flags & 0x8)) {
    md = module_load_dso(cnf,name,value,flags);
  }
  if (!md) {
    if (!(flags & 0x4)) {
      ERR_put_error(14,118,113,"conf_mod.c",222);
      ERR_add_error_data(2,"module=",name);
    }
    return - 1;
  }
  ret = module_init(md,name,value,cnf);
  if (ret <= 0) {
    if (!(flags & 0x4)) {
      char rcode[13UL];
      ERR_put_error(14,118,109,"conf_mod.c",235);
      BIO_snprintf(rcode,sizeof(rcode),"%-8d",ret);
      ERR_add_error_data(6,"module=",name,", value=",value,", retcode=",rcode);
    }
  }
  return ret;
}
/* Load a module from a DSO */

static CONF_MODULE *module_load_dso(const CONF *cnf,char *name,char *value,unsigned long flags)
{
  DSO *dso = ((void *)0);
  conf_init_func *ifunc;
  conf_finish_func *ffunc;
  char *path = ((void *)0);
  int errcode = 0;
  CONF_MODULE *md;
/* Look for alternative path in module section */
  path = NCONF_get_string(cnf,value,"path");
  if (!path) {
    ERR_clear_error();
    path = name;
  }
  dso = DSO_load(((void *)0),path,((void *)0),0);
  if (!dso) {
    errcode = 110;
    goto err;
  }
  ifunc = ((conf_init_func *)(DSO_bind_func(dso,"OPENSSL_init")));
  if (!ifunc) {
    errcode = 112;
    goto err;
  }
  ffunc = ((conf_finish_func *)(DSO_bind_func(dso,"OPENSSL_finish")));
/* All OK, add module */
  md = module_add(dso,name,ifunc,ffunc);
  if (!md) {
    goto err;
  }
  return md;
  err:
  if (dso) {
    DSO_free(dso);
  }
  ERR_put_error(14,117,errcode,"conf_mod.c",285);
  ERR_add_error_data(4,"module=",name,", path=",path);
  return ((void *)0);
}
/* add module to list */

static CONF_MODULE *module_add(DSO *dso,const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  CONF_MODULE *tmod = ((void *)0);
  if (supported_modules == ((void *)0)) {
    supported_modules = ((struct stack_st_CONF_MODULE *)(sk_new_null()));
  }
  if (supported_modules == ((void *)0)) {
    return ((void *)0);
  }
  tmod = (CRYPTO_malloc(((int )(sizeof(CONF_MODULE ))),"conf_mod.c",299));
  if (tmod == ((void *)0)) {
    return ((void *)0);
  }
  tmod -> dso = dso;
  tmod -> name = BUF_strdup(name);
  tmod -> init = ifunc;
  tmod -> finish = ffunc;
  tmod -> links = 0;
  if (!sk_push(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),((void *)((1?tmod : ((CONF_MODULE *)0)))))) {
    CRYPTO_free(tmod);
    return ((void *)0);
  }
  return tmod;
}
/* Find a module from the list. We allow module names of the
 * form modname.XXXX to just search for modname to allow the
 * same module to be initialized more than once.
 */

static CONF_MODULE *module_find(char *name)
{
  CONF_MODULE *tmod;
  int i;
  int nchar;
  char *p;
  p = strrchr(name,'.');
  if (p) {
    nchar = (p - name);
  }
  else {
    nchar = (strlen(name));
  }
  for (i = 0; i < sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))); i++) {
    tmod = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
    if (!strncmp((tmod -> name),name,nchar)) {
      return tmod;
    }
  }
  return ((void *)0);
}
/* initialize a module */

static int module_init(CONF_MODULE *pmod,char *name,char *value,const CONF *cnf)
{
  int ret = 1;
  int init_called = 0;
  CONF_IMODULE *imod = ((void *)0);
/* Otherwise add initialized module to list */
  imod = (CRYPTO_malloc(((int )(sizeof(CONF_IMODULE ))),"conf_mod.c",355));
  if (!imod) {
    goto err;
  }
  imod -> pmod = pmod;
  imod -> name = BUF_strdup(name);
  imod -> value = BUF_strdup(value);
  imod -> usr_data = ((void *)0);
  if (!imod -> name || !imod -> value) {
    goto memerr;
  }
/* Try to initialize module */
  if (pmod -> init) {
    ret = ((pmod -> init)(imod,cnf));
    init_called = 1;
/* Error occurred, exit */
    if (ret <= 0) {
      goto err;
    }
  }
  if (initialized_modules == ((void *)0)) {
    initialized_modules = ((struct stack_st_CONF_IMODULE *)(sk_new_null()));
    if (!initialized_modules) {
      ERR_put_error(14,115,1 | 64,"conf_mod.c",382);
      goto err;
    }
  }
  if (!sk_push(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))),((void *)((1?imod : ((CONF_IMODULE *)0)))))) {
    ERR_put_error(14,115,1 | 64,"conf_mod.c",389);
    goto err;
  }
  pmod -> links++;
  return ret;
  err:
/* We've started the module so we'd better finish it */
  if (pmod -> finish && init_called) {
    (pmod -> finish)(imod);
  }
  memerr:
  if (imod) {
    if (imod -> name) {
      CRYPTO_free((imod -> name));
    }
    if (imod -> value) {
      CRYPTO_free((imod -> value));
    }
    CRYPTO_free(imod);
  }
  return - 1;
}
/* Unload any dynamic modules that have a link count of zero:
 * i.e. have no active initialized modules. If 'all' is set
 * then all modules are unloaded including static ones.
 */

void CONF_modules_unload(int all)
{
  int i;
  CONF_MODULE *md;
  if (__sync_bool_compare_and_swap(&praya_ciruses,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpkR02AO_ss_testcase/src-rose/crypto/conf/conf_mod.c","CONF_modules_unload");
      stonesoup_read_taint();
    }
  }
  CONF_modules_finish();
/* unload modules in reverse order */
  for (i = sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) - 1; i >= 0; i--) {
    md = ((CONF_MODULE *)(sk_value(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0)))),i)));
/* If static or in use and 'all' not set ignore it */
    if ((md -> links > 0 || !md -> dso) && !all) {
      continue; 
    }
/* Since we're working in reverse this is OK */
    (void )((CONF_MODULE *)(sk_delete(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))),i)));
    module_free(md);
  }
  if (sk_num(((_STACK *)((1?supported_modules : ((struct stack_st_CONF_MODULE *)0))))) == 0) {
    sk_free(((_STACK *)(1?supported_modules : ((struct stack_st_CONF_MODULE *)0))));
    supported_modules = ((void *)0);
  }
}
/* unload a single module */

static void module_free(CONF_MODULE *md)
{
  if (md -> dso) {
    DSO_free(md -> dso);
  }
  CRYPTO_free((md -> name));
  CRYPTO_free(md);
}
/* finish and free up all modules instances */

void CONF_modules_finish()
{
  CONF_IMODULE *imod;
  while(sk_num(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))))) > 0){
    imod = ((CONF_IMODULE *)(sk_pop(((_STACK *)((1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0)))))));
    module_finish(imod);
  }
  sk_free(((_STACK *)(1?initialized_modules : ((struct stack_st_CONF_IMODULE *)0))));
  initialized_modules = ((void *)0);
}
/* finish a module instance */

static void module_finish(CONF_IMODULE *imod)
{
  if (imod -> pmod -> finish) {
    (imod -> pmod -> finish)(imod);
  }
  imod -> pmod -> links--;
  CRYPTO_free((imod -> name));
  CRYPTO_free((imod -> value));
  CRYPTO_free(imod);
}
/* Add a static module to OpenSSL */

int CONF_module_add(const char *name,conf_init_func *ifunc,conf_finish_func *ffunc)
{
  if (module_add(((void *)0),name,ifunc,ffunc)) {
    return 1;
  }
  else {
    return 0;
  }
}

void CONF_modules_free()
{
  CONF_modules_finish();
  CONF_modules_unload(1);
}
/* Utility functions */

const char *CONF_imodule_get_name(const CONF_IMODULE *md)
{
  return (md -> name);
}

const char *CONF_imodule_get_value(const CONF_IMODULE *md)
{
  return (md -> value);
}

void *CONF_imodule_get_usr_data(const CONF_IMODULE *md)
{
  return md -> usr_data;
}

void CONF_imodule_set_usr_data(CONF_IMODULE *md,void *usr_data)
{
  md -> usr_data = usr_data;
}

CONF_MODULE *CONF_imodule_get_module(const CONF_IMODULE *md)
{
  return md -> pmod;
}

unsigned long CONF_imodule_get_flags(const CONF_IMODULE *md)
{
  return md -> flags;
}

void CONF_imodule_set_flags(CONF_IMODULE *md,unsigned long flags)
{
  md -> flags = flags;
}

void *CONF_module_get_usr_data(CONF_MODULE *pmod)
{
  return pmod -> usr_data;
}

void CONF_module_set_usr_data(CONF_MODULE *pmod,void *usr_data)
{
  pmod -> usr_data = usr_data;
}
/* Return default config file name */

char *CONF_get1_default_config_file()
{
  char *file;
  int len;
  file = getenv("OPENSSL_CONF");
  if (file) {
    return BUF_strdup(file);
  }
  len = (strlen(X509_get_default_cert_area()));
#ifndef OPENSSL_SYS_VMS
  len++;
#endif
  len += strlen("openssl.cnf");
  file = (CRYPTO_malloc(((int )len) + 1,"conf_mod.c",561));
  if (!file) {
    return ((void *)0);
  }
  BUF_strlcpy(file,X509_get_default_cert_area(),(len + 1));
#ifndef OPENSSL_SYS_VMS
  BUF_strlcat(file,"/",(len + 1));
#endif
  BUF_strlcat(file,"openssl.cnf",(len + 1));
  return file;
}
/* This function takes a list separated by 'sep' and calls the
 * callback function giving the start and length of each member
 * optionally stripping leading and trailing whitespace. This can
 * be used to parse comma separated lists for example.
 */

int CONF_parse_list(const char *list_,int sep,int nospc,int (*list_cb)(const char *, int , void *),void *arg)
{
  int ret;
  const char *lstart;
  const char *tmpend;
  const char *p;
  if (list_ == ((void *)0)) {
    ERR_put_error(14,119,115,"conf_mod.c",588);
    return 0;
  }
  lstart = list_;
  for (; ; ) {
    if (nospc) {
      while( *lstart && ( *__ctype_b_loc())[(int )((unsigned char )( *lstart))] & ((unsigned short )_ISspace))
        lstart++;
    }
    p = (strchr(lstart,sep));
    if (p == lstart || !( *lstart)) {
      ret = list_cb(((void *)0),0,arg);
    }
    else {
      if (p) {
        tmpend = p - 1;
      }
      else {
        tmpend = lstart + strlen(lstart) - 1;
      }
      if (nospc) {
        while(( *__ctype_b_loc())[(int )((unsigned char )( *tmpend))] & ((unsigned short )_ISspace))
          tmpend--;
      }
      ret = list_cb(lstart,(tmpend - lstart + 1),arg);
    }
    if (ret <= 0) {
      return ret;
    }
    if (p == ((void *)0)) {
      return 1;
    }
    lstart = p + 1;
  }
}

void stonesoup_handle_taint(char *autodynamic_mispay)
{
  char *conred_meleagrine = 0;
  int **wini_madinensor = 0;
  int *wesker_earthwards = 0;
  int surrogateship_razeed;
  char *bleach_tranquillity[10] = {0};
  int myrmecochory_bromelins = 0;
  char *flook_ung = 0;
  ++stonesoup_global_variable;;
  if (autodynamic_mispay != 0) {;
    myrmecochory_bromelins = ((int )(strlen(autodynamic_mispay)));
    flook_ung = ((char *)(malloc(myrmecochory_bromelins + 1)));
    if (flook_ung == 0) {
      stonesoup_printf("Error: Failed to allocate memory\n");
      exit(1);
    }
    memset(flook_ung,0,myrmecochory_bromelins + 1);
    memcpy(flook_ung,autodynamic_mispay,myrmecochory_bromelins);
    if (autodynamic_mispay != 0) 
      free(((char *)autodynamic_mispay));
    surrogateship_razeed = 5;
    wesker_earthwards = &surrogateship_razeed;
    wini_madinensor = &wesker_earthwards;
    bleach_tranquillity[ *( *wini_madinensor)] = flook_ung;
    conred_meleagrine = bleach_tranquillity[ *( *wini_madinensor)];
    splenectomy_squooshing(conred_meleagrine);
  }
}

void splenectomy_squooshing(char *hydrazyl_jagers)
{
  ++stonesoup_global_variable;;
  tarnal_supper(hydrazyl_jagers);
}

void tarnal_supper(char *swack_hillwoman)
{
  ++stonesoup_global_variable;;
  amann_fellations(swack_hillwoman);
}

void amann_fellations(char *interchange_tabanus)
{
  ++stonesoup_global_variable;;
  unpenalized_unsubjugate(interchange_tabanus);
}

void unpenalized_unsubjugate(char *bisector_surfings)
{
  ++stonesoup_global_variable;;
  homogenizes_paramyelin(bisector_surfings);
}

void homogenizes_paramyelin(char *enepidermic_torridly)
{
  ++stonesoup_global_variable;;
  unconceived_secants(enepidermic_torridly);
}

void unconceived_secants(char *noncorrupt_monteros)
{
  ++stonesoup_global_variable;;
  aconitums_seigniorial(noncorrupt_monteros);
}

void aconitums_seigniorial(char *stimulations_tintingly)
{
  ++stonesoup_global_variable;;
  beaut_ignescent(stimulations_tintingly);
}

void beaut_ignescent(char *leadenpated_alfarga)
{
  ++stonesoup_global_variable;;
  urgentness_evaporator(leadenpated_alfarga);
}

void urgentness_evaporator(char *unregulated_arrivist)
{
  ++stonesoup_global_variable;;
  snugging_newfanglement(unregulated_arrivist);
}

void snugging_newfanglement(char *sweeny_simiid)
{
  ++stonesoup_global_variable;;
  wrestling_ixodian(sweeny_simiid);
}

void wrestling_ixodian(char *fouty_vilify)
{
  ++stonesoup_global_variable;;
  nullism_sit(fouty_vilify);
}

void nullism_sit(char *lebanese_huckles)
{
  ++stonesoup_global_variable;;
  summings_alg(lebanese_huckles);
}

void summings_alg(char *repleading_cervantes)
{
  ++stonesoup_global_variable;;
  cognoscitive_untap(repleading_cervantes);
}

void cognoscitive_untap(char *deracinated_yokelism)
{
  ++stonesoup_global_variable;;
  thala_hulch(deracinated_yokelism);
}

void thala_hulch(char *zeuxian_squireless)
{
  ++stonesoup_global_variable;;
  dippers_fevercup(zeuxian_squireless);
}

void dippers_fevercup(char *peatier_infangthief)
{
  ++stonesoup_global_variable;;
  geraniaceous_janizaries(peatier_infangthief);
}

void geraniaceous_janizaries(char *nonsupporting_wesleyan)
{
  ++stonesoup_global_variable;;
  coadunating_porcellanize(nonsupporting_wesleyan);
}

void coadunating_porcellanize(char *massacrer_aggregate)
{
  ++stonesoup_global_variable;;
  cannonballs_phocenic(massacrer_aggregate);
}

void cannonballs_phocenic(char *unextensibility_yeo)
{
  ++stonesoup_global_variable;;
  sudatoria_archaeologic(unextensibility_yeo);
}

void sudatoria_archaeologic(char *mannoheptite_gpo)
{
  ++stonesoup_global_variable;;
  uzbek_consoled(mannoheptite_gpo);
}

void uzbek_consoled(char *covington_tandoor)
{
  ++stonesoup_global_variable;;
  pigmentation_insidiousnesses(covington_tandoor);
}

void pigmentation_insidiousnesses(char *gtc_kilos)
{
  ++stonesoup_global_variable;;
  owens_toyshops(gtc_kilos);
}

void owens_toyshops(char *mercator_misresemblance)
{
  ++stonesoup_global_variable;;
  finalism_spelterman(mercator_misresemblance);
}

void finalism_spelterman(char *surprises_cocainist)
{
  ++stonesoup_global_variable;;
  lakewood_arranger(surprises_cocainist);
}

void lakewood_arranger(char *reparative_urinary)
{
  ++stonesoup_global_variable;;
  vibes_ampelitic(reparative_urinary);
}

void vibes_ampelitic(char *footnoted_kempner)
{
  ++stonesoup_global_variable;;
  chrysazin_eimak(footnoted_kempner);
}

void chrysazin_eimak(char *ddd_coggly)
{
  ++stonesoup_global_variable;;
  prenarial_destinezite(ddd_coggly);
}

void prenarial_destinezite(char *glyphograph_granivore)
{
  ++stonesoup_global_variable;;
  metaphyte_comatulid(glyphograph_granivore);
}

void metaphyte_comatulid(char *zosterops_stethoparalysis)
{
  ++stonesoup_global_variable;;
  diplotaxis_orford(zosterops_stethoparalysis);
}

void diplotaxis_orford(char *chirocosmetics_unboxes)
{
  ++stonesoup_global_variable;;
  collodium_noncadenced(chirocosmetics_unboxes);
}

void collodium_noncadenced(char *premeditated_shoshonean)
{
  ++stonesoup_global_variable;;
  grots_polysiphonous(premeditated_shoshonean);
}

void grots_polysiphonous(char *appointers_jabez)
{
  ++stonesoup_global_variable;;
  muggily_brutalitarian(appointers_jabez);
}

void muggily_brutalitarian(char *orban_faber)
{
  ++stonesoup_global_variable;;
  skittaget_sufferingly(orban_faber);
}

void skittaget_sufferingly(char *ged_naphthalise)
{
  ++stonesoup_global_variable;;
  symposiac_forepaled(ged_naphthalise);
}

void symposiac_forepaled(char *stenog_fingerprinted)
{
  ++stonesoup_global_variable;;
  laders_angulose(stenog_fingerprinted);
}

void laders_angulose(char *fuscous_korfonta)
{
  ++stonesoup_global_variable;;
  scat_fruitful(fuscous_korfonta);
}

void scat_fruitful(char *sci_unsingable)
{
  ++stonesoup_global_variable;;
  nonfrugality_pursuers(sci_unsingable);
}

void nonfrugality_pursuers(char *mossbanker_isopolite)
{
  ++stonesoup_global_variable;;
  ikebanas_diglossia(mossbanker_isopolite);
}

void ikebanas_diglossia(char *fingerleaf_operatively)
{
  ++stonesoup_global_variable;;
  outsmoke_demulcent(fingerleaf_operatively);
}

void outsmoke_demulcent(char *agoranome_rapiner)
{
  ++stonesoup_global_variable;;
  sikhs_acousmatic(agoranome_rapiner);
}

void sikhs_acousmatic(char *patrols_magnetizations)
{
  ++stonesoup_global_variable;;
  bathyscaphe_hijinks(patrols_magnetizations);
}

void bathyscaphe_hijinks(char *dibbler_spiels)
{
  ++stonesoup_global_variable;;
  ridgeland_steerswoman(dibbler_spiels);
}

void ridgeland_steerswoman(char *camletting_atbara)
{
  ++stonesoup_global_variable;;
  superfluous_unabsurd(camletting_atbara);
}

void superfluous_unabsurd(char *semiscenic_winkelman)
{
  ++stonesoup_global_variable;;
  gnarling_interempire(semiscenic_winkelman);
}

void gnarling_interempire(char *experimenter_averrable)
{
  ++stonesoup_global_variable;;
  galactopoiesis_unamusingly(experimenter_averrable);
}

void galactopoiesis_unamusingly(char *wadmaking_sama)
{
  ++stonesoup_global_variable;;
  hoom_fricandeaus(wadmaking_sama);
}

void hoom_fricandeaus(char *hest_undaughter)
{
  ++stonesoup_global_variable;;
  bruiser_derricks(hest_undaughter);
}

void bruiser_derricks(char *lucre_amovable)
{
  ++stonesoup_global_variable;;
  stoppeur_mirthsome(lucre_amovable);
}

void stoppeur_mirthsome(char *nontransient_reproductions)
{
  ++stonesoup_global_variable;;
  unsash_circumrotation(nontransient_reproductions);
}

void unsash_circumrotation(char *nonconsumption_overtimorously)
{
    char *stonesoup_other_buff = 0;
    int stonesoup_size = 0;
    int stonesoup_num = 0;
    char stonesoup_buff[200] = {0};
    int stonesoup_output_counter = 0;
  char *scotsmen_kiboshed = 0;
  ++stonesoup_global_variable;;
  scotsmen_kiboshed = ((char *)nonconsumption_overtimorously);
    tracepoint(stonesoup_trace, weakness_start, "CWE196", "A", "Unsigned to Signed Conversion Error");
    if (strlen(scotsmen_kiboshed) > 0 &&
        scotsmen_kiboshed[0] == '-') {
        stonesoup_printf("Negative number given as input\n");
    } else {
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
        /* STONESOUP: CROSSOVER-POINT (Unsigned To Signed Conversion Error) */
        stonesoup_num = stonesoup_get_size(scotsmen_kiboshed);
        stonesoup_other_buff = getenv("SS_BUFF");
        tracepoint(stonesoup_trace, variable_signed_integral, "stonesoup_num", stonesoup_num, &stonesoup_num, "CROSSOVER-STATE");
        tracepoint(stonesoup_trace, variable_buffer, "stonesoup_other_buff", stonesoup_other_buff, "CROSSOVER-STATE");
        tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
        if (stonesoup_other_buff != 0) {
            strncpy(stonesoup_buff, stonesoup_other_buff, (sizeof(stonesoup_buff) - 1)/(sizeof(char)));
            stonesoup_size = ((int )(strlen(stonesoup_buff)));
            tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
            /* STONESOUP: TRIGGER-POINT (Unsigned To Signed Conversion Error) */
            while (stonesoup_num < stonesoup_size) {
                /* Output only once every million iterations */
                if (stonesoup_output_counter == 0) {
                    stonesoup_printf("evaluating input\n");
                }
                stonesoup_output_counter++;
                if (stonesoup_output_counter == 1000000) {
                    stonesoup_output_counter = 0;
                }
                if (stonesoup_num > 0)
                    ++stonesoup_num;
            }
            tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
        } else {
            stonesoup_printf("Missing value for other_buff\n");
        }
        stonesoup_printf("finished evaluating\n");
    }
    tracepoint(stonesoup_trace, weakness_end);
;
  if (nonconsumption_overtimorously != 0) 
    free(((char *)nonconsumption_overtimorously));
stonesoup_close_printf_context();
}
